@@ -184,6 +184,10 @@ def sync(config, state, stream):
     seq_number_bookmarks = singer.get_bookmark(state, table_name, 'shard_seq_numbers')
     if not seq_number_bookmarks:
         seq_number_bookmarks = {}
+    LOGGER.info("seq number bookmarks : %s",seq_number_bookmarks)
+    LOGGER.info("stream arn value : %s",stream_arn)
+    LOGGER.info("state : %s",state)
+
 
     # Get the list of closed shards which we have fully synced. These
     # are removed after performing a sync and not seeing the shardId
@@ -202,7 +206,7 @@ def sync(config, state, stream):
 
     for shard in get_shards(streams_client, stream_arn):
         found_shards.append(shard['ShardId'])
-        # Only sync shards which we have not fully synced alreadymake      
+        # Only sync shards which we have not fully synced already     
         rows_synced += sync_shard(shard, seq_number_bookmarks,
                                     streams_client, stream_arn, projection, deserializer,
                                     table_name, stream_version, state)
